@@ -35,6 +35,7 @@
 #include "devicesignalmapmanager.h"
 #include "devicesignalmapper.h"
 #include "hddtemp.h"
+#include <KIO/FileSystemFreeSpaceJob>
 
 enum State {
     Idle = 0,
@@ -80,7 +81,7 @@ private:
     QMap<QString, Solid::Device> m_devicemap;
     //udi, corresponding encrypted container udi;
     QMap<QString, QString> m_encryptedContainerMap;
-    //path, for pending file system free space jobs
+    //path, corresponding timer
     QSet<QString> m_paths;
     DeviceSignalMapManager *m_signalmanager;
 
